@@ -75,7 +75,7 @@ SICHEL <-function (mu.link ="log", sigma.link="log", nu.link="identity")
                    ty <- gamlss.dist:::tofySICHEL(y=y, mu=mu, sigma=sigma, nu=nu, what=1)
                  dldm <- (y-ty)/mu
                  #calculates the dldv                 
-                   nd <- gamlss:::numeric.deriv(dSICHEL(y, mu, sigma, nu, log=TRUE), "nu", delta=0.001)
+                   nd <- gamlss.dist:::numeric.deriv(dSICHEL(y, mu, sigma, nu, log=TRUE), "nu", delta=0.001)
                  dldv <- as.vector(attr(nd, "gradient"))
                 #calculates the d2ldmdv
               d2ldmdv <- -dldm *dldv
@@ -87,14 +87,14 @@ SICHEL <-function (mu.link ="log", sigma.link="log", nu.link="identity")
                  dcdd <- (c*sigma*(2*nu+1)+1-c*c)/(sigma*sigma)   
                  dldd <- (((ty*(c+sigma*mu)/mu) - (sigma*y)-c)/(sigma^2))+dcdd*(ty-y)/c
                 #calculates the dldv
-                   nd <- gamlss:::numeric.deriv(dSICHEL(y, mu, sigma, nu, log=TRUE), "nu", delta=0.001)
+                   nd <- gamlss.dist:::numeric.deriv(dSICHEL(y, mu, sigma, nu, log=TRUE), "nu", delta=0.001)
                  dldv <- as.vector(attr(nd, "gradient"))
                 #calculates the d2ldddv 
               d2ldddv <- -dldd *dldv
               d2ldddv
                                  },               
                  dldv = function(y,mu,sigma,nu) {                           
-                   nd <- gamlss:::numeric.deriv(dSICHEL(y, mu, sigma, nu, log=TRUE), "nu", delta=0.001)
+                   nd <- gamlss.dist:::numeric.deriv(dSICHEL(y, mu, sigma, nu, log=TRUE), "nu", delta=0.001)
                  dldv <- as.vector(attr(nd, "gradient"))
                  dldv
                                     },
@@ -102,7 +102,7 @@ SICHEL <-function (mu.link ="log", sigma.link="log", nu.link="identity")
                 #  delta  <- 0.01
                 #    dldv <- (dSI(y=y, mu=mu, sigma=sigma, nu=nu+delta, log = TRUE)- 
                 #            dSI(y=y, mu=mu, sigma=sigma, nu=nu, log= TRUE))/ delta   
-                   nd <- gamlss:::numeric.deriv(dSICHEL(y, mu, sigma, nu, log=TRUE), "nu", delta=0.001)
+                   nd <- gamlss.dist:::numeric.deriv(dSICHEL(y, mu, sigma, nu, log=TRUE), "nu", delta=0.001)
                  dldv <- as.vector(attr(nd, "gradient"))
                d2ldv2 <- -dldv*dldv
                d2ldv2
@@ -339,7 +339,7 @@ rSICHEL <- function(n, mu=1, sigma=1, nu=-0.5, max.value = 10000)
 #----------------------------------------------------------------------------------------
 VSICHEL<- function(obj)
  {
- if (!is.gamlss(obj)) stop("The object is not a gamlss object")
+ #if (!is.gamlss(obj)) stop("The object is not a gamlss object")
  if (obj$family[1]!="SICHEL") stop("The distribution is not a Sichel distribution")
      mu <- fitted(obj,"mu")
   sigma <- fitted(obj,"sigma")
